#  Copyright (c) 2025, Helloblue Inc.
#  Open-Source Community Edition

#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to use,
#  copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
#  the Software, subject to the following conditions:

#  1. The above copyright notice and this permission notice shall be included in
#     all copies or substantial portions of the Software.
#  2. Contributions to this project are welcome and must adhere to the project's
#     contribution guidelines.
#  3. The name "Helloblue Inc." and its contributors may not be used to endorse
#     or promote products derived from this software without prior written consent.

#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
#  THE SOFTWARE.

import os

import joblib


class VulnerabilityDetector:
    def __init__(self, model_path=None):
        self.model = None
        if model_path and os.path.exists(model_path):
            self.model = joblib.load(model_path)

    def detect_vulnerabilities(self, code):
        """Scan Python code for security risks."""
        issues = []
        if not isinstance(code, str):
            return issues

        if "eval(" in code:
            issues.append("⚠️ `eval()` usage detected. This is a major security risk!")
        if "exec(" in code:
            issues.append("⚠️ `exec()` usage detected. This is a major security risk!")
        if "os.system(" in code:
            issues.append("⚠️ `os.system()` usage detected. This is a security risk!")

        return issues


if __name__ == "__main__":
    detector = VulnerabilityDetector()
    sample_code = "user_input = input(); eval(user_input)"
    vulnerabilities = detector.detect_vulnerabilities(sample_code)
    print("🚨 Vulnerabilities:", vulnerabilities)
